import { NextFunction, Request, Response } from "express";
import { Redis } from "../db/redis/Redis";
import { RegisterModel } from "../models/DarioRegisterModel";
import { User } from "../common/types/User";

export class DarioRegisterController {
  redis: Redis;
  registerModel: RegisterModel;

  constructor() {
    this.redis = new Redis();
    this.registerModel = new RegisterModel();
  }

  async connectToRedis() {
    await this.redis.connect();
  }

  public async verifyEligibility(
    req: Request,
    res: Response
  ) {
    const { key } = req.body;
    try {
      const user: any = await this.redis.findUserByKey(key);
      res.status(200).json(user);
    } catch (error) {
      console.error(error.message);
      res.status(500).send("Internal Server Error");
    }
  }

  public async register(req: Request, res: Response, next: NextFunction) {
    const { email, key, name, phone } = req.body;
    try {
      const user: any = await this.redis.findUserByKey(key);
      if (!user) return res.status(404).send("User not found");

      const isUserVerified: boolean = this.verifyUser(user, email, name, phone);

      if (isUserVerified) {
        await this.registerModel.create(user);
        await this.redis.deleteUserByKey(key);
        res.status(200).send("User registered");
      } else {
        res.status(404).send("User not found");
      }
    } catch (error) {
      console.error(error.message);
      res.status(500).send("Internal Server Error");
    }
  }

  private verifyUser(
    user: User,
    email: string,
    name: string,
    phone: string
  ): boolean {
    console.log(user.Phone !== phone);
    return user.Email === email && user.Name.toLocaleLowerCase() === name.toLocaleLowerCase() && user.Phone === phone;
  }
}
