import UserModel from '../db/mongodb/schema'; // Import the user schema/model
import mongoose from 'mongoose';
import { User } from '../common/types/User';
import dotenv from 'dotenv';

const envVars = dotenv.config().parsed;

export class RegisterModel {

  async connect() {
    try {
      await mongoose.connect(envVars.MONGO_CONNECTION_URL);
      console.log('Connected to MongoDB');
    } catch (error) {
      console.error('Error connecting to MongoDB:', error);
    }
  }

  async disconnect() {
    try {
      await mongoose.disconnect();
      console.log('Disconnected from MongoDB');
    } catch (error) {
      console.error('Error disconnecting from MongoDB:', error);
    }
  }

  async create(userInput: User) {
    try {
      this.connect();
      const user = new UserModel(userInput);
      console.log(user)
      return await user.save();
    } catch (error) {
      throw new Error('Error creating user: ' + error);
    } finally {
      this.disconnect();
    }
  }

  async getByEmail(email: string) {
    try {
      return await UserModel.findOne({ Email: email });
    } catch (error) {
      throw new Error('Error getting user by email: ' + error);
    }
  }

  async delete(email: string) {
    try {
      const user = await UserModel.findOne({ Email: email });
      if (user) {
        user.active = false;
        return await user.save();
      }
    } catch (error) {
      throw new Error('Error deleting user: ' + error);
    }
  }

  async updateUpdatedAt(email: string) {
    try {
      const user = await UserModel.findOne({ Email: email });
      if (user) {
        user.updated_at = new Date();
        return await user.save();
      }
    } catch (error) {
      throw new Error('Error updating updated_at: ' + error);
    }
  }
}
